/*
 * Copyright 2002-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.didion.vfs.provider.crypt;

import org.apache.commons.vfs.FileSystemConfigBuilder;
import org.apache.commons.vfs.FileSystemOptions;

import java.util.Map;
import java.util.HashMap;

public class CryptFileSystemConfigBuilder extends FileSystemConfigBuilder {
    public static final String FILE_CIPHER_INFO_KEY = "crypt.fileCipherInfo";
    public static final String DEFAULT_CIPHER_INFO_KEY = "crypt.defaultCipherInfo";
    public static final String DEFAULT_KEY_KEY = "crypt.defaultKey";

    private static final CryptFileSystemConfigBuilder instance =
            new CryptFileSystemConfigBuilder();


    public static CryptFileSystemConfigBuilder getInstance() {
        return instance;
    }

    private CryptFileSystemConfigBuilder() {
    }

    public void setDefaultCipherInfo(FileSystemOptions opts, CipherInfo info) {
        setParam(opts, DEFAULT_CIPHER_INFO_KEY, info);
    }

    public CipherInfo getDefaultCipherInfo(FileSystemOptions opts) {
        return (CipherInfo) getParam(opts, DEFAULT_CIPHER_INFO_KEY);
    }

    public void setCipherInfo(
            FileSystemOptions opts,
            String fileUri,
            CipherInfo info) {
        Map cipherInfo = getCipherInfoMap(opts);
        cipherInfo.put(fileUri, info);
    }

    public CipherInfo getCipherInfo(FileSystemOptions opts, String fileUri) {
        return (CipherInfo) getCipherInfoMap(opts).get(fileUri);
    }

    public Map getCipherInfoMap(FileSystemOptions opts) {
        Map cipherInfo = (Map) getParam(opts, FILE_CIPHER_INFO_KEY);
        if (null == cipherInfo) {
            cipherInfo = new HashMap();
            setParam(opts, FILE_CIPHER_INFO_KEY, cipherInfo);
        }
        return cipherInfo;
    }

    protected Class getConfigClass() {
        return CryptFileSystem.class;
    }
}